@@ -1,4 +1,5 @@
 import itertools
+import os
 
 import numpy as np
 import pandas as pd
@@ -7,6 +8,11 @@ from typing import Callable, Any, Union, Tuple, Dict
 from typing import Dict
 from adlinear import testers as tst
 from adlinear import utilities as utl
+from adlinear import nmfmodel as nmf
+from pathlib import Path
+import root_path
+import dotenv
+dotenv.load_dotenv()
 
 
 class RandomVariable:
@@ -231,13 +237,70 @@ class DependentLocalizedSignals:
         return self
 
 
-class RandomFeatures ():
-    pass
+def generate_nmf_reconstruction(n_comp: int,
+                                min_intra_corr: float,
+                                max_inter_corr: float,
+                                h_avg_clust_size: int,
+                                w_avg_clust_size: int,
+                                epsilon: float):
+    cl_vects_H = utl.generate_clusterized_vectors(veclen=n_comp,
+                                                  nclusters=n_comp,
+                                                  nbvect=n_comp * h_avg_clust_size,
+                                                  clusterminsize=int(h_avg_clust_size/2),
+                                                  max_inter_corr=max_inter_corr,
+                                                  min_intra_corr=min_intra_corr)
+    cl_vects_W = utl.generate_clusterized_vectors(veclen=nb_clusters,
+                                                  nclusters=nb_clusters,
+                                                  nbvect=nb_clusters * w_avg_clust_size,
+                                                  clusterminsize=int(w_avg_clust_size/2),
+                                                  max_inter_corr=max_inter_corr,
+                                                  min_intra_corr=min_intra_corr)
+    cl_vects_W = cl_vects_W.T
+    cl_vects_M = cl_vects_W @ cl_vects_H
+    noise = np.random.normal(loc=0.0, scale=epsilon, size=cl_vects_M.shape)
+    cl_vects_M *= 1 + noise
+    cl_vects_M = np.maximum(cl_vects_M, 0)
+    return cl_vects_M
 
 
 if __name__ == "__main__":
+    # localisation du modèle GAN
+    root_path = root_path.get_root_path()
+
+    rd_path = root_path / os.getenv("rd_subpath")
+    imputation_paper_path = rd_path / os.getenv("imputation_paper_subpath")
+
+    data_path = imputation_paper_path / os.getenv("data_subpath")
+    res_path = imputation_paper_path / os.getenv("results_subpath")
+
+    # df_mini_scree_plots = pd.read_csv(res_path / "random_nmf" / f"mini_scree_plots.csv")
+    df_mini_scree_plots = pd.DataFrame(index=[], columns=[])
+
+    for itrial in range(40):
+        nb_clusters = np.random.randint(low=5, high=50)
+        min_corr = np.random.uniform(low=0.85, high=0.95)
+        max_corr = np.random.uniform(low=0.05, high=0.15)
+        h_avg_csize = np.random.randint(low=10, high=20)
+        w_avg_csize = np.random.randint(low=10, high=50)
+        eps = np.random.uniform(low=0.05, high=0.20)
+        generated_M = generate_nmf_reconstruction(n_comp=nb_clusters,
+                                                  min_intra_corr=min_corr,
+                                                  max_inter_corr=max_corr,
+                                                  h_avg_clust_size=h_avg_csize,
+                                                  w_avg_clust_size=w_avg_csize,
+                                                  epsilon=eps)
+        generated_M.to_csv(res_path / "random_nmf" / f"M_nc{nb_clusters}_corrmin{round(min_corr,2)}_"
+                                       f"corrmax{round(max_corr,2)}_noise{round(eps,2)}.csv",
+                           float_format="%.4f")
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=5, ncmax=50)
+        df_mini_scree_plots = nmf.add_examples_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
+        df_mini_scree_plots.to_csv(res_path / "random_nmf" / f"mini_scree_plots.csv")
+
+    do_read_mat = False
+    if do_read_mat:
+        mat_name = "M_nc36_corrmin0.92_corrmax0.13_noise0.11"
+        M = pd.read_csv(res_path / "random_nmf" / f"{mat_name}.csv")
+        df_scree_plot = nmf.generate_scree_plot(M, ncmin=25, ncmax=40)
+        df_scree_plot.to_csv(res_path / "random_nmf" / f"{mat_name}_screeplot.csv")
 
-    dfc = utl.generate_clusters_centroids(ndim=10, max_corr=0.1)
-    v = dfc.iloc[:, 0]
-    dfb = utl.generate_vectors_bouquet(v, 20, 0.9)
     pass
